@@ -13,6 +13,10 @@ ATTR_DEVICE_MODEL_NAME = "modelName"
 ATTR_DEVICE_PARENT_ID = "parentDeviceId"
 ATTR_DEVICE_SERVICE_ZONE = "serviceZone"
 
+ATTR_DEVICE_MODEL_A = "A"
+ATTR_DEVICE_MODEL_C = "C"
+ATTR_DEVICE_MODEL_D = "D"
+
 ATTR_DEVICE_DOOR_SENSOR = "DoorSensor"
 ATTR_DEVICE_TH_SENSOR = "THSensor"
 ATTR_DEVICE_MOTION_SENSOR = "MotionSensor"
@@ -35,6 +39,7 @@ ATTR_DEVICE_SPEAKER_HUB = "SpeakerHub"
 ATTR_DEVICE_FINGER = "Finger"
 ATTR_DEVICE_WATER_DEPTH_SENSOR = "WaterDepthSensor"
 ATTR_DEVICE_WATER_METER_CONTROLLER = "WaterMeterController"
+ATTR_DEVICE_MULTI_WATER_METER_CONTROLLER = "WaterMeterMultiController"
 ATTR_DEVICE_LOCK_V2 = "LockV2"
 
 UNIT_NOT_RECOGNIZED_TEMPLATE: Final = "{} is not a recognized {} unit."
